/*
 @C:\Win_Prj\Sql\Oracle\5008_DF_STP_Consulta_GrupoFiscal.sql

 Descrio:
 Procedure para consulta do grupo fiscal que ser utilizado na parametrizao fiscal

 Criao:
 29/08/2001 - Roberto A. Lopes Martins

 Parmetros

 P_IDORIGDESTNF - Identificador de origem e destino do lanamento
                  "F" - Fornecedor
                  "C" - Cliente
                  "L" = Filial
 P_CDORIGDESTNF - Cdigo da pessoa de origem ou destino do lanamento. Depende do primeiro parmetro.
 P_CDFILIFATUR  - Cdigo da filial emitente da nota fiscal em caso de documento de faturamento.
                  Se no for nota fiscal gerada atravs de apurao de faturamento = ''.
 P_IDENTRSAIDOP - Sentido da Operao
                  "E" - Entrada
                  "S" - Sada
 P_CDTIPOOPER   - Tipo de Operao do lanamento
 P_CDGRUPOFISC  - Parmetro que retorna o grupo fiscal utilizado.


 Exemplo da utilizao.

 Esta procedure deve ser chamada apenas uma vez dentro da procedure, no  necessrio executar a
 cada vez que for chamar as procedures de consulta de parametrizao fiscal.

 "
 ...
 CONSULTA_GRUPOFISCAL(V_IDORIGDESTNF, V_CDFORNECED, '', 'E', V_CDTIPOOPER, V_CDGRUPOFISC);
 ...

 CONSULTA_ALIQUOTA(V_CDIMPOSTO, 'E', V_CDEMPRESA, V_CDPRODUTO, V_CDINSCESTA,
                   V_CDPAISORIG, V_SGESTAORIG, V_CDPAISDEST, V_SGESTADEST, V_CDMUNIORIG,
                   V_VRBASECALC, V_DTINIVALID, V_CDFILIAL, V_NRLANCTONF, V_CDGRUPOFISC);
 ...
 "
*/

CREATE OR REPLACE PROCEDURE CONSULTA_GRUPOFISCAL
   (P_IDORIGDESTNF IN NOTAFISCAL.IDORIGDESTNF%TYPE,
    P_CDORIGDESTNF IN FORNECEDOR.CDFORNECED%TYPE,
    P_CDFILIFATUR  IN FILIAL.CDFILIAL%TYPE,
    P_IDENTRSAIDOP IN TIPOOPERAC.IDENTRSAIDOP%TYPE,
    P_CDTIPOOPER   IN TIPOOPERAC.CDTIPOOPER%TYPE,
    P_CDGRUPOFISC OUT NoCopy GRUPOFISCAL.CDGRUPOFISC%TYPE)

IS

   V_CDGRUPOFISC GRUPOFISCAL.CDGRUPOFISC%TYPE;

BEGIN
   V_CDGRUPOFISC := NULL;

   IF P_IDORIGDESTNF = 'F' THEN
      Begin
        SELECT CDGRUPOFISC
        INTO   V_CDGRUPOFISC
        FROM FORNECEDOR
        WHERE CDFORNECED = P_CDORIGDESTNF;
      Exception
         When No_Data_Found Then
            V_CDGRUPOFISC := Null;
      End;

   ELSIF P_IDORIGDESTNF = 'C' THEN

      Begin
        SELECT CDGRUPOFISC
        INTO   V_CDGRUPOFISC
        FROM CLIENTE
        WHERE CDCLIENTE = P_CDORIGDESTNF;
      Exception
         When No_Data_Found Then
            V_CDGRUPOFISC := Null;
      End;

   ELSE
     Begin
        SELECT CDGRUPOFISC
        INTO   V_CDGRUPOFISC
        FROM FILIAL
        WHERE CDFILIAL = P_CDORIGDESTNF;
      Exception
         When No_Data_Found Then
            V_CDGRUPOFISC := Null;
      End;
   END IF;

   IF V_CDGRUPOFISC IS NULL THEN
      Begin
        SELECT CDGRUPOFISC
        INTO   V_CDGRUPOFISC
        FROM PARAMFILIAL
        WHERE CDFILIAL = P_CDFILIFATUR;
      Exception
         When No_Data_Found Then
            V_CDGRUPOFISC := Null;
      End;

   END IF;

   IF V_CDGRUPOFISC IS NULL THEN
      Begin
        SELECT CDGRUPOFISC
        INTO   V_CDGRUPOFISC
        FROM TIPOOPERAC
        WHERE IDENTRSAIDOP = P_IDENTRSAIDOP AND
              CDTIPOOPER   = P_CDTIPOOPER;
      Exception
         When No_Data_Found Then
            V_CDGRUPOFISC := Null;
      End;
   END IF;

   IF V_CDGRUPOFISC IS NULL THEN

      Begin
        SELECT CDGRUPOFISC
        INTO   V_CDGRUPOFISC
        FROM TPFATURFIS T, FILTPFATURFIS F
        WHERE T.CDTPFATURFIS = F.CDTPFATURFIS
          AND F.CDFILIAL     = P_CDFILIFATUR;
      Exception
         When No_Data_Found Then
            V_CDGRUPOFISC := Null;
      End;

   END IF;

   P_CDGRUPOFISC := V_CDGRUPOFISC;
END;
/

-- VERSAO --
BEGIN ATUVEROBJ('CONSULTA_GRUPOFISCAL','5.01.014'); END;
/

